@@ -5,15 +5,14 @@ from suite_py.lib.singleton import Singleton
 
 
 class Logger(metaclass=Singleton):
-
     def __init__(self):
         pass
 
     def info(self, message):
-        print(colored(message, 'green'))
+        print(colored(message, "green"))
 
     def warning(self, message):
-        print(colored(message, 'yellow'))
+        print(colored(message, "yellow"))
 
     def error(self, message):
-        print(colored(message, 'red'))
+        print(colored(message, "red"))
